@@ -9,7 +9,7 @@ library(tidyfst)
 
 # nest by "cyl" column
 mtcars_nested <- mtcars %>% 
-  nest_by("cyl")
+  nest_dt(cyl) # you can use "cyl" too, very flexible
 
 # inspect the output data.table
 mtcars_nested
@@ -27,5 +27,5 @@ mtcars_nested3 <- mtcars_nested2 %>%
 mtcars_nested3$model_predict
 
 ## -----------------------------------------------------------------------------
-mtcars_nested3 %>% unnest_col(model_predict)
+mtcars_nested3 %>% unnest_dt(model_predict)
 
